"use client";
import { ChangeEvent, FormEvent, useEffect, useState } from "react";
import { addWine } from "../../server/actions/addWine";
import { getProducers } from "../../server/actions/allProducers";
import { Producer } from "~/types/types";

export default function CreateWine() {
  const [name, setName] = useState<string>("");
  const [producer, setProducer] = useState<string>("");
  const [allProducers, setAllProducers] = useState<Producer[]>([]);

  useEffect(() => {
    const fetchProducers = async () => {
      try {
        const producers = await getProducers();
        setAllProducers(producers);
      } catch (error) {
        console.error("Failed to fetch producers:", error);
      }
    };
    fetchProducers();
  }, []);

  const handleName = (event: ChangeEvent<HTMLInputElement>) => {
    setName(event.target.value);
  };
  const handleProducer = (event: ChangeEvent<HTMLSelectElement>) => {
    setProducer(event.target.value);
  };
  const handleAdd = async (event: FormEvent) => {
    event.preventDefault();
    console.log(producer);
    addWine(producer, name);
    setName("");
  };
  return (
    <div>
      <input type="text" onChange={handleName} value={name} />
      <select
        name="producer"
        id="producer"
        value={producer}
        onChange={handleProducer}
      >
        {allProducers.map((item, i) => (
          <option key={i} value={item.id}>
            {item.name}
          </option>
        ))}
      </select>
      <button onClick={handleAdd}>Submit wine</button>
    </div>
  );
}
